import React from 'react';
import { useEffect } from 'react';
import { Code, Rocket, Bot, Zap, ArrowRight, Workflow, Database, Globe, Layout, Target, CheckCircle2 } from 'lucide-react';
import { Link } from 'react-router-dom';
import Footer from '../components/Footer';

const CustomDevelopment = () => {
  useEffect(() => {
    document.title = 'Custom AI Solutions - Tailored Communication & Automation | Sales Assist AI';
    // Update meta description
    const metaDescription = document.querySelector('meta[name="description"]');
    if (metaDescription) {
      metaDescription.setAttribute('content', 'Transform your business with custom AI solutions tailored to your unique needs. From intelligent chatbots to complete automation systems, we build scalable solutions that streamline operations and accelerate growth.');
    }
  }, []);

  const capabilities = [
    {
      icon: <Bot className="w-6 h-6" />,
      title: 'AI Integration',
      description: 'Custom AI solutions tailored to your specific business needs, from chatbots to predictive analytics'
    },
    {
      icon: <Workflow className="w-6 h-6" />,
      title: 'Automation Systems',
      description: 'Bespoke automation workflows that streamline your unique business processes'
    },
    {
      icon: <Database className="w-6 h-6" />,
      title: 'Data Solutions',
      description: 'Custom databases and analytics platforms built for your specific data requirements'
    },
    {
      icon: <Globe className="w-6 h-6" />,
      title: 'Web Applications',
      description: 'Scalable, custom web applications designed to solve your unique challenges'
    }
  ];

  const features = [
    {
      icon: <Target className="w-8 h-8" />,
      title: 'Tailored Solutions',
      description: 'Every solution is built specifically for your business needs and goals'
    },
    {
      icon: <Layout className="w-8 h-8" />,
      title: 'Modern Architecture',
      description: 'Built with the latest technologies for performance and scalability'
    },
    {
      icon: <Zap className="w-8 h-8" />,
      title: 'Rapid Development',
      description: 'Efficient development process to get your solution live faster'
    }
  ];

  return (
    <div>
      <div className="min-h-screen bg-white">
        <div className="container pt-24 pb-12">
          {/* Hero Section */}
          <div className="text-center mb-16">
            <div className="inline-flex items-center gap-2 px-4 py-2 rounded-full bg-primary-50 border border-primary-100 mb-4">
              <div className="p-1 bg-gradient-to-r from-primary-500 to-primary-600 rounded-full">
                <Code className="w-4 h-4 text-white" />
              </div>
              <span className="text-sm font-medium text-primary-700">
                CUSTOM DEVELOPMENT
              </span>
            </div>
            
            <h1 className="text-4xl sm:text-5xl font-bold text-secondary-900 mb-6">
              Bringing Your Vision
              <span className="block text-gradient mt-2">To Life</span>
            </h1>
            
            <p className="text-xl text-secondary-600 max-w-3xl mx-auto mb-8">
              We specialize in building custom software solutions that streamline your business operations and drive growth. From AI integration to automation systems, we bring your ideas to reality.
            </p>

            <div className="flex justify-center gap-4">
              <a 
                href="/book-demo" 
                className="btn-primary group"
              >
                Discuss Your Project
                <ArrowRight className="ml-2 w-5 h-5 group-hover:translate-x-0.5 transition-transform" />
              </a>
            </div>
          </div>

          {/* Features Grid */}
          <div className="grid md:grid-cols-3 gap-8 mb-24">
            {features.map((feature, index) => (
              <div key={index} className="group bg-white rounded-2xl p-6 border border-primary-100/50 shadow-soft hover:shadow-lg transition-all">
                <div className="w-16 h-16 rounded-xl bg-primary-50 flex items-center justify-center mb-6 group-hover:scale-110 transition-transform">
                  <div className="text-primary-600">
                    {feature.icon}
                  </div>
                </div>
                <h3 className="text-xl font-semibold text-secondary-900 mb-3">
                  {feature.title}
                </h3>
                <p className="text-secondary-600">
                  {feature.description}
                </p>
              </div>
            ))}
          </div>

          {/* Capabilities Section */}
          <div className="mb-24">
            <div className="text-center mb-12">
              <h2 className="text-3xl font-bold text-secondary-900 mb-4">
                Our Development
                <span className="block text-gradient mt-2">Capabilities</span>
              </h2>
              <p className="text-lg text-secondary-600 max-w-2xl mx-auto">
                We bring expertise across multiple domains to deliver comprehensive solutions for your business
              </p>
            </div>

            <div className="grid md:grid-cols-2 gap-6">
              {capabilities.map((capability, index) => (
                <div key={index} className="bg-white rounded-2xl p-6 border border-primary-100/50 shadow-soft">
                  <div className="flex items-start gap-4">
                    <div className="w-12 h-12 rounded-xl bg-primary-50 flex items-center justify-center shrink-0">
                      <div className="text-primary-600">
                        {capability.icon}
                      </div>
                    </div>
                    <div>
                      <h3 className="text-lg font-semibold text-secondary-900 mb-2">
                        {capability.title}
                      </h3>
                      <p className="text-secondary-600">
                        {capability.description}
                      </p>
                    </div>
                  </div>
                </div>
              ))}
            </div>
          </div>

          {/* CTA Section */}
          <div className="bg-gradient-to-br from-primary-50 to-white rounded-3xl p-8 md:p-12 border border-primary-100/50 shadow-soft text-center">
            <div className="max-w-3xl mx-auto">
              <h2 className="text-3xl font-bold text-secondary-900 mb-4">
                Ready to Build Your
                <span className="block text-gradient mt-2">Custom Solution?</span>
              </h2>
              <p className="text-lg text-secondary-600 mb-8">
                Let's discuss how we can help streamline your business with a custom-built solution tailored to your needs.
              </p>
              <div className="flex justify-center gap-4">
                <a 
                  href="/book-demo" 
                  className="btn-primary group"
                >
                  Start Your Project
                  <ArrowRight className="ml-2 w-5 h-5 group-hover:translate-x-0.5 transition-transform" />
                </a>
              </div>
            </div>
          </div>
        </div>
      </div>
      <Footer />
    </div>
  );
};

export default CustomDevelopment;